@@ -53,6 +53,10 @@ UDT_power <- function(case_a, case_b, mean_a = 0, mean_b = 0,
                       alternative = c("two.sided", "greater", "less"),
                       alpha = 0.05, spec = 0.005) {
 
+  ###
+  # Set up error messages
+  ###
+
   if (!is.null(sample_size) & !is.null(power)) stop("Must supply only one of sample size or desired power")
   if (is.null(sample_size) & is.null(power)) stop("Must supply either sample size or desired power")
   if (!is.null(power)) if (power > 1 | power < 0) stop("Desired power must be between 0 and 1")
@@ -64,6 +68,10 @@ UDT_power <- function(case_a, case_b, mean_a = 0, mean_b = 0,
 
   n = sample_size
 
+  ###
+  # Calculate analytic power depending on hypothesis
+  ###
+
   if (is.null(power)) {
 
     if (alternative == "two.sided") {
@@ -113,6 +121,11 @@ UDT_power <- function(case_a, case_b, mean_a = 0, mean_b = 0,
 
   }
 
+  ###
+  # Deploy search algorithm to find sample
+  # size given power
+  ###
+
   if (is.null(sample_size)) {
 
     n = 2
@@ -238,6 +251,10 @@ RSDT_power <- function(case_a, case_b, mean_a = 0, mean_b = 0,
                        alternative = c("two.sided", "greater", "less"),
                        alpha = 0.05, nsim = 10000) {
 
+  ###
+  # Set up error messages
+  ###
+
   if (!is.null(sample_size)) if (sample_size < 2) stop("Sample size must be greater than 1")
   if (alpha < 0 | alpha > 1) stop("Type I error rate must be between 0 and 1")
   if (r_ab < -1 | r_ab > 1) stop("Correlation between task a and b must be between -1 and 1")
@@ -246,6 +263,11 @@ RSDT_power <- function(case_a, case_b, mean_a = 0, mean_b = 0,
 
   n = sample_size
 
+  ###
+  # Create function that calculates p-value from
+  # simulated cases and samples
+  ###
+
   rsdt_p_sim <- function(case_a, case_b,mean_a, mean_b,
                          sd_a, sd_b, r_ab) {
 
@@ -268,6 +290,11 @@ RSDT_power <- function(case_a, case_b, mean_a = 0, mean_b = 0,
   }
 
 
+  ###
+  # Simulate p-values nsim number of times
+  ###
+
+
   pval <- vector(length = nsim)
 
   for(i in 1:nsim) {
@@ -277,6 +304,10 @@ RSDT_power <- function(case_a, case_b, mean_a = 0, mean_b = 0,
 
   }
 
+  ###
+  # Calculate the percentage of which these p-values are less than alpha
+  ###
+
   power = sum(pval < alpha)/length(pval)
 
 
@@ -335,6 +366,10 @@ BSDT_power <- function(case_a, case_b, mean_a = 0, mean_b = 0,
                        alpha = 0.05, nsim = 1000, iter = 1000,
                        calibrated = TRUE) {
 
+  ###
+  # Set up error messages
+  ###
+
   if (!is.null(sample_size)) if (sample_size < 2) stop("Sample size must be greater than 1")
   if (alpha < 0 | alpha > 1) stop("Type I error rate must be between 0 and 1")
   if (r_ab < -1 | r_ab > 1) stop("Correlation between task a and b must be between -1 and 1")
@@ -343,6 +378,10 @@ BSDT_power <- function(case_a, case_b, mean_a = 0, mean_b = 0,
 
   n = sample_size
 
+  ###
+  # Define function for simulating case and controls based on the values given
+  ###
+
   bsdt_p_sim <- function() {
 
     cor_mat <- matrix(c(1, r_ab, r_ab, 1), nrow = 2)
@@ -364,6 +403,9 @@ BSDT_power <- function(case_a, case_b, mean_a = 0, mean_b = 0,
     pval
   }
 
+  ###
+  # Simulate p-values nsim number of times
+  ###
 
   pval <- vector(length = nsim)
 
@@ -373,6 +415,10 @@ BSDT_power <- function(case_a, case_b, mean_a = 0, mean_b = 0,
 
   }
 
+  ###
+  # Calculate the percentage of which these p-values are below alpha
+  ###
+
   power = sum(pval < alpha)/length(pval)
 
 
@@ -406,7 +452,7 @@ BSDT_power <- function(case_a, case_b, mean_a = 0, mean_b = 0,
 #'   of covariates. Defaults to one covariate with mean 0 and sd = 1.
 #' @param cor_mat A correlation matrix containing the correlations of the tasks
 #'   of interest and the coviariate(s). The first two variables are treated as
-#'   the tasks of interest. Defaults to no correlation between any.
+#'   the tasks of interest. Defaults pairwise correlations between the variates of 0.3.
 #' @param sample_size Single value giving the size of the control sample for which you wish
 #'   to calculate power.
 #' @param alternative The alternative hypothesis. A string of either "less",
@@ -432,18 +478,26 @@ BSDT_power <- function(case_a, case_b, mean_a = 0, mean_b = 0,
 #' sample_size = 10, cor_mat = diag(5), iter = 20, nsim = 20)
 
 BSDT_cov_power <- function(case_tasks, case_cov, control_tasks = matrix(c(0, 0, 1, 1), ncol= 2), control_covar = c(0, 1),
-                          cor_mat = diag(3),
+                          cor_mat = diag(3) + 0.3 - diag(c(0.3, 0.3, 0.3)),
                           sample_size,
                           alternative = c("two.sided", "greater", "less"),
                           alpha = 0.05,
                           nsim = 1000, iter = 1000,
                           calibrated = TRUE) {
 
+  ###
+  # Set up error messages
+  ###
+
   if (alpha < 0 | alpha > 1) stop("Type I error rate must be between 0 and 1")
   if (sum(eigen(cor_mat)$values > 0) < length(diag(cor_mat))) stop("cor_mat is not positive definite")
   if (sample_size < 2) stop("Sample size must be greater than 1")
   if (length(case_tasks) != 2) stop("case_tasks should be of length 2")
 
+  ###
+  # Extract needed statistics
+  ###
+
   alternative <- match.arg(alternative)
   n = sample_size
 
@@ -454,6 +508,10 @@ BSDT_cov_power <- function(case_tasks, case_cov, control_tasks = matrix(c(0, 0,
   Sigma <- diag(sum_stats[ , 2]) %*% cor_mat %*% diag(sum_stats[ , 2])
   mu <- sum_stats[ , 1]
 
+  ###
+  # Define function for simulating case and controls based on the values given
+  ###
+
   BSDT_cov_p_sim <- function() {
 
 
@@ -476,6 +534,9 @@ BSDT_cov_power <- function(case_tasks, case_cov, control_tasks = matrix(c(0, 0,
     pval
   }
 
+  ###
+  # Simulate p-values nsim number of times
+  ###
 
   pval <- vector(length = nsim)
 
@@ -485,6 +546,10 @@ BSDT_cov_power <- function(case_tasks, case_cov, control_tasks = matrix(c(0, 0,
 
   }
 
+  ###
+  # Calculate the percentage of which these p-values are below alpha
+  ###
+
   power = sum(pval < alpha)/length(pval)
 
   return(power)
